==> rice-impex-master-2.1.15-sql.jar: sql/oracle/KRIM_ENTITY_T.sql <==
TRUNCATE TABLE KRIM_ENTITY_T DROP STORAGE
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1',TO_DATE( '20081107094902', 'YYYYMMDDHH24MISS' ),'5B1B6B919CC96496E0404F8189D822F2',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1100',TO_DATE( '20081113140635', 'YYYYMMDDHH24MISS' ),'5B97C50B03946110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1101',TO_DATE( '20081113140636', 'YYYYMMDDHH24MISS' ),'5B97C50B03956110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1102',TO_DATE( '20081113140636', 'YYYYMMDDHH24MISS' ),'5B97C50B03966110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1103',TO_DATE( '20081113140636', 'YYYYMMDDHH24MISS' ),'5B97C50B03976110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1104',TO_DATE( '20081113140636', 'YYYYMMDDHH24MISS' ),'5B97C50B03986110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1105',TO_DATE( '20081113140636', 'YYYYMMDDHH24MISS' ),'5B97C50B03996110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1106',TO_DATE( '20081113140636', 'YYYYMMDDHH24MISS' ),'5B97C50B039A6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1107',TO_DATE( '20081113140637', 'YYYYMMDDHH24MISS' ),'5B97C50B039B6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1108',TO_DATE( '20081113140637', 'YYYYMMDDHH24MISS' ),'5B97C50B039C6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1109',TO_DATE( '20081113140637', 'YYYYMMDDHH24MISS' ),'5B97C50B039D6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1110',TO_DATE( '20081113140637', 'YYYYMMDDHH24MISS' ),'5B97C50B039E6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1111',TO_DATE( '20081113140637', 'YYYYMMDDHH24MISS' ),'5B97C50B039F6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1112',TO_DATE( '20081113140637', 'YYYYMMDDHH24MISS' ),'5B97C50B03A06110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1113',TO_DATE( '20081113140638', 'YYYYMMDDHH24MISS' ),'5B97C50B03A16110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1114',TO_DATE( '20081113140638', 'YYYYMMDDHH24MISS' ),'5B97C50B03A26110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1115',TO_DATE( '20081113140638', 'YYYYMMDDHH24MISS' ),'5B97C50B03A36110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1116',TO_DATE( '20081113140638', 'YYYYMMDDHH24MISS' ),'5B97C50B03A46110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1117',TO_DATE( '20081113140638', 'YYYYMMDDHH24MISS' ),'5B97C50B03A56110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1118',TO_DATE( '20081113140638', 'YYYYMMDDHH24MISS' ),'5B97C50B03A66110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1119',TO_DATE( '20081113140638', 'YYYYMMDDHH24MISS' ),'5B97C50B03A76110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1120',TO_DATE( '20081113140639', 'YYYYMMDDHH24MISS' ),'5B97C50B03A86110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1121',TO_DATE( '20081113140639', 'YYYYMMDDHH24MISS' ),'5B97C50B03A96110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1122',TO_DATE( '20081113140639', 'YYYYMMDDHH24MISS' ),'5B97C50B03AA6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1123',TO_DATE( '20081113140639', 'YYYYMMDDHH24MISS' ),'5B97C50B03AB6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1124',TO_DATE( '20081113140639', 'YYYYMMDDHH24MISS' ),'5B97C50B03AC6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1125',TO_DATE( '20081113140639', 'YYYYMMDDHH24MISS' ),'5B97C50B03AD6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1126',TO_DATE( '20081113140640', 'YYYYMMDDHH24MISS' ),'5B97C50B03AE6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1127',TO_DATE( '20081113140640', 'YYYYMMDDHH24MISS' ),'5B97C50B03AF6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1128',TO_DATE( '20081113140640', 'YYYYMMDDHH24MISS' ),'5B97C50B03B06110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1129',TO_DATE( '20081113140640', 'YYYYMMDDHH24MISS' ),'5B97C50B03B16110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1130',TO_DATE( '20081113140640', 'YYYYMMDDHH24MISS' ),'5B97C50B03B26110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1131',TO_DATE( '20081113140640', 'YYYYMMDDHH24MISS' ),'5B97C50B03B36110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1132',TO_DATE( '20081113140641', 'YYYYMMDDHH24MISS' ),'5B97C50B03B46110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1133',TO_DATE( '20081113140641', 'YYYYMMDDHH24MISS' ),'5B97C50B03B56110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1134',TO_DATE( '20081113140641', 'YYYYMMDDHH24MISS' ),'5B97C50B03B66110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1135',TO_DATE( '20081113140641', 'YYYYMMDDHH24MISS' ),'5B97C50B03B76110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1136',TO_DATE( '20081113140641', 'YYYYMMDDHH24MISS' ),'5B97C50B03B86110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1137',TO_DATE( '20081113140641', 'YYYYMMDDHH24MISS' ),'5B97C50B03B96110E0404F8189D85213',1)
/

==> rice-impex-master-2.5.10-sql.jar: sql/oracle/KRIM_ENTITY_T.sql <==
TRUNCATE TABLE KRIM_ENTITY_T DROP STORAGE
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1',TO_DATE( '20081107094902', 'YYYYMMDDHH24MISS' ),'5B1B6B919CC96496E0404F8189D822F2',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1100',TO_DATE( '20081113140635', 'YYYYMMDDHH24MISS' ),'5B97C50B03946110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1101',TO_DATE( '20081113140636', 'YYYYMMDDHH24MISS' ),'5B97C50B03956110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1102',TO_DATE( '20081113140636', 'YYYYMMDDHH24MISS' ),'5B97C50B03966110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1103',TO_DATE( '20081113140636', 'YYYYMMDDHH24MISS' ),'5B97C50B03976110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1104',TO_DATE( '20081113140636', 'YYYYMMDDHH24MISS' ),'5B97C50B03986110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1105',TO_DATE( '20081113140636', 'YYYYMMDDHH24MISS' ),'5B97C50B03996110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1106',TO_DATE( '20081113140636', 'YYYYMMDDHH24MISS' ),'5B97C50B039A6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1107',TO_DATE( '20081113140637', 'YYYYMMDDHH24MISS' ),'5B97C50B039B6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1108',TO_DATE( '20081113140637', 'YYYYMMDDHH24MISS' ),'5B97C50B039C6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1109',TO_DATE( '20081113140637', 'YYYYMMDDHH24MISS' ),'5B97C50B039D6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1110',TO_DATE( '20081113140637', 'YYYYMMDDHH24MISS' ),'5B97C50B039E6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1111',TO_DATE( '20081113140637', 'YYYYMMDDHH24MISS' ),'5B97C50B039F6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1112',TO_DATE( '20081113140637', 'YYYYMMDDHH24MISS' ),'5B97C50B03A06110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1113',TO_DATE( '20081113140638', 'YYYYMMDDHH24MISS' ),'5B97C50B03A16110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1114',TO_DATE( '20081113140638', 'YYYYMMDDHH24MISS' ),'5B97C50B03A26110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1115',TO_DATE( '20081113140638', 'YYYYMMDDHH24MISS' ),'5B97C50B03A36110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1116',TO_DATE( '20081113140638', 'YYYYMMDDHH24MISS' ),'5B97C50B03A46110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1117',TO_DATE( '20081113140638', 'YYYYMMDDHH24MISS' ),'5B97C50B03A56110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1118',TO_DATE( '20081113140638', 'YYYYMMDDHH24MISS' ),'5B97C50B03A66110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1119',TO_DATE( '20081113140638', 'YYYYMMDDHH24MISS' ),'5B97C50B03A76110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1120',TO_DATE( '20081113140639', 'YYYYMMDDHH24MISS' ),'5B97C50B03A86110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1121',TO_DATE( '20081113140639', 'YYYYMMDDHH24MISS' ),'5B97C50B03A96110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1122',TO_DATE( '20081113140639', 'YYYYMMDDHH24MISS' ),'5B97C50B03AA6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1123',TO_DATE( '20081113140639', 'YYYYMMDDHH24MISS' ),'5B97C50B03AB6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1124',TO_DATE( '20081113140639', 'YYYYMMDDHH24MISS' ),'5B97C50B03AC6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1125',TO_DATE( '20081113140639', 'YYYYMMDDHH24MISS' ),'5B97C50B03AD6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1126',TO_DATE( '20081113140640', 'YYYYMMDDHH24MISS' ),'5B97C50B03AE6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1127',TO_DATE( '20081113140640', 'YYYYMMDDHH24MISS' ),'5B97C50B03AF6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1128',TO_DATE( '20081113140640', 'YYYYMMDDHH24MISS' ),'5B97C50B03B06110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1129',TO_DATE( '20081113140640', 'YYYYMMDDHH24MISS' ),'5B97C50B03B16110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1130',TO_DATE( '20081113140640', 'YYYYMMDDHH24MISS' ),'5B97C50B03B26110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1131',TO_DATE( '20081113140640', 'YYYYMMDDHH24MISS' ),'5B97C50B03B36110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1132',TO_DATE( '20081113140641', 'YYYYMMDDHH24MISS' ),'5B97C50B03B46110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1133',TO_DATE( '20081113140641', 'YYYYMMDDHH24MISS' ),'5B97C50B03B56110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1134',TO_DATE( '20081113140641', 'YYYYMMDDHH24MISS' ),'5B97C50B03B66110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1135',TO_DATE( '20081113140641', 'YYYYMMDDHH24MISS' ),'5B97C50B03B76110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1136',TO_DATE( '20081113140641', 'YYYYMMDDHH24MISS' ),'5B97C50B03B86110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1137',TO_DATE( '20081113140641', 'YYYYMMDDHH24MISS' ),'5B97C50B03B96110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','KR1000',TO_DATE( '20121130172303', 'YYYYMMDDHH24MISS' ),'CFBAA6F5F0D05D07E0406E0AC31D229B',1)
/
